<?php
/**
 * Popular Destination section
 *
 * This is the template for the content of popular destination section
 *
 * @package Theme Palace
 * @subpackage Travel Master Pro
 * @since Travel Master Pro 1.0.0
 */
if ( ! function_exists( 'travel_master_pro_add_popular_destination_section' ) ) :
    /**
    * Add popular destination section
    *
    *@since Travel Master Pro 1.0.0
    */
    function travel_master_pro_add_popular_destination_section() {
    	$options = travel_master_pro_get_theme_options();
        // Check if destination is enabled on frontpage
        $popular_destination_enable = apply_filters( 'travel_master_pro_section_status', true, 'popular_destination_section_enable' );

        if ( true !== $popular_destination_enable ) {
            return false;
        }
        // Get destination section details
        $section_details = array();
        $section_details = apply_filters( 'travel_master_pro_filter_popular_destination_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render destination section now.
        travel_master_pro_render_popular_destination_section( $section_details );
    }
endif;

if ( ! function_exists( 'travel_master_pro_get_popular_destination_section_details' ) ) :
    /**
    * popular destination section details.
    *
    * @since Travel Master Pro 1.0.0
    * @param array $input popular destination section details.
    */
    function travel_master_pro_get_popular_destination_section_details( $input ) {
        $options = travel_master_pro_get_theme_options();

        // Content type.
        $popular_destination_content_type  = $options['popular_destination_content_type'];
        $popular_destination_count = ! empty( $options['popular_destination_count'] ) ? $options['popular_destination_count'] : 3;
        
        $content = array();
        switch ( $popular_destination_content_type ) {
        	
            case 'category':
                $cat_id = ! empty( $options['popular_destination_content_category'] ) ? $options['popular_destination_content_category'] : '';
                $args = array(
                    'post_type'         => 'post',
                    'posts_per_page'    => absint( $popular_destination_count ),
                    'cat'               => absint( $cat_id ),
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'page':
                $page_ids = array();

                for ( $i = 1; $i <= $popular_destination_count; $i++ ) {
                    if ( ! empty( $options['popular_destination_content_page_' . $i] ) )
                        $page_ids[] = $options['popular_destination_content_page_' . $i];
                }
                
                $args = array(
                    'post_type'         => 'page',
                    'post__in'          => ( array ) $page_ids,
                    'posts_per_page'    => absint( $popular_destination_count ),
                    'orderby'           => 'post__in',
                    );                    
            break;

            case 'post':
                $post_ids = array();

                for ( $i = 1; $i <= $popular_destination_count; $i++ ) {
                    if ( ! empty( $options['popular_destination_content_post_' . $i] ) )
                        $post_ids[] = $options['popular_destination_content_post_' . $i];
                }
                
                $args = array(
                    'post_type'         => 'post',
                    'post__in'          => ( array ) $post_ids,
                    'posts_per_page'    => absint( $popular_destination_count ),
                    'orderby'           => 'post__in',
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'trip':
                if ( ! class_exists( 'WP_Travel' ) )
                    return;

                $page_ids = array();

                for ( $i = 1; $i <= $popular_destination_count; $i++ ) {
                    if ( ! empty( $options['popular_destination_content_trip_' . $i] ) )
                        $page_ids[] = $options['popular_destination_content_trip_' . $i];
                }
                
                $args = array(
                    'post_type'         => 'itineraries',
                    'post__in'          => ( array ) $page_ids,
                    'posts_per_page'    => absint( $popular_destination_count ),
                    'orderby'           => 'post__in',
                    );                    
            break;

            case 'trip-types':
                if ( ! class_exists( 'WP_Travel' ) )
                    return;

                $cat_id = ! empty( $options['popular_destination_content_trip_types'] ) ? $options['popular_destination_content_trip_types'] : '';
                $args = array(
                    'post_type'      => 'itineraries',
                    'tax_query' => array(
                        array(
                            'taxonomy' => 'itinerary_types',
                            'field'    => 'id',
                            'terms'    => $cat_id,
                        ),
                    ),
                    'posts_per_page'  => absint( $popular_destination_count ),
                    );                    
            break;

            case 'destination':
                if ( ! class_exists( 'WP_Travel' ) )
                    return;

                $cat_id = ! empty( $options['popular_destination_content_destination'] ) ? $options['popular_destination_content_destination'] : '';
                $args = array(
                    'post_type'      => 'itineraries',
                    'tax_query' => array(
                        array(
                            'taxonomy' => 'travel_locations',
                            'field'    => 'id',
                            'terms'    => $cat_id,
                        ),
                    ),
                    'posts_per_page'  => absint( $popular_destination_count ),
                    );                    
            break;

            case 'activity':
                if ( ! class_exists( 'WP_Travel' ) )
                    return;
                
                $cat_id = ! empty( $options['popular_destination_content_activity'] ) ? $options['popular_destination_content_activity'] : '';
                $args = array(
                    'post_type'      => 'itineraries',
                    'tax_query' => array(
                        array(
                            'taxonomy' => 'activity',
                            'field'    => 'id',
                            'terms'    => $cat_id,
                        ),
                    ),
                    'posts_per_page'  => absint( $popular_destination_count ),
                    );                    
            break;

            default:
            break;
        }


            // Run The Loop.
            $query = new WP_Query( $args );
            if ( $query->have_posts() ) : 
                while ( $query->have_posts() ) : $query->the_post();
                    $page_post['id']        = get_the_id();
                    $page_post['title']     = get_the_title();
                    $page_post['url']       = get_the_permalink();
                    $page_post['image']  	= has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'post-thumbnail' ) : get_template_directory_uri() . '/assets/uploads/no-featured-image-590x650.jpg';

                    // Push to the main array.
                    array_push( $content, $page_post );
                endwhile;
            endif;
            wp_reset_postdata();

            
        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// destination section content details.
add_filter( 'travel_master_pro_filter_popular_destination_section_details', 'travel_master_pro_get_popular_destination_section_details' );


if ( ! function_exists( 'travel_master_pro_render_popular_destination_section' ) ) :
  /**
   * Start destination section
   *
   * @return string destination content
   * @since Travel Master Pro 1.0.0
   *
   */
   function travel_master_pro_render_popular_destination_section( $content_details = array() ) {
        $options = travel_master_pro_get_theme_options();
        $popular_destination_content_type  = $options['popular_destination_content_type'];

        if ( empty( $content_details ) ) {
            return;
        } ?>

        <div id="top-destinations" class="relative page-section">
            <div class="wrapper">
                <div class="section-header-wrapper clear">
                    <div class="section-header">
                        <?php if ( ! empty( $options['popular_destination_title'] ) ) : ?>
                            <h2 class="section-title"><?php echo esc_html( $options['popular_destination_title'] ); ?></h2>
                        <?php endif;

                        if ( ! empty( $options['popular_destination_btn_title'] ) && ! empty( $options['popular_destination_btn_url'] ) ) : ?>
                            <a href="<?php echo esc_url( $options['popular_destination_btn_url'] ); ?>" class="more-link">
                                <?php 
                                    echo esc_html( $options['popular_destination_btn_title'] );
                                    echo travel_master_pro_get_svg( array( 'icon' => 'right' ) ); 
                                ?>
                            </a>
                        <?php endif; ?>

                    </div><!-- .section-header -->

                    <?php if ( ! in_array( $popular_destination_content_type, array( 'category', 'page', 'post' ) ) ) : ?>
                        <div class="destination-filter">
                            <?php  
                                $destinations = get_terms( array(
                                    'taxonomy' => 'travel_locations',
                                    'hide_empty' => false,
                                ) );
                            ?>

                            <select onChange="window.location.href=this.value">
                                <?php foreach ( $destinations as $destination ) : ?>
                                <option value="<?php echo esc_url( get_term_link( $destination->term_id, 'travel_locations' ) ); ?>"><?php echo esc_html( $destination->name ); ?></option>
                                <?php endforeach; ?>
                            </select>

                        </div><!-- .destination-filter -->
                    <?php endif; ?>    
                </div><!-- .section-header-wrapper -->

                <div class="section-content col-<?php echo absint( $options['popular_destination_column_type'] ); ?> clear">
                    <?php foreach ( $content_details as $content ) : ?>
                        <article>
                            <div class="destination-item-wrapper">
                                <div class="featured-image" style="background-image: url('<?php echo esc_url( $content['image'] ); ?>');">
                                    <div class="overlay"></div>
                                    <a href="<?php echo esc_url( $content['url'] ) ?>" class="more-link">
                                        <?php echo travel_master_pro_get_svg( array( 'icon' => 'add' ) ); ?>
                                    </a><!-- .more-link -->

                                    <?php if ( ! in_array( $popular_destination_content_type, array( 'category', 'page', 'post' ) ) ) : 
                                        $price_key = '';
                                        $sale_enabled = get_post_meta( $content['id'], 'wp_travel_enable_sale', true );
                                        if( wp_travel_is_enable_pricing_options( $content['id'] ) ) {
                                            
                                            $pricing_options = get_post_meta( $content['id'], 'wp_travel_pricing_options', true );
                                            $price_key = wp_travel_get_min_price_key( $pricing_options );
                                        }

                                        $trip_price = wp_travel_get_price( $content['id'], $price_key );
                                        
                                        if ( wp_travel_tab_show_in_menu( 'reviews' ) ) :
                                        $average_rating = wp_travel_get_average_rating( $content['id'] ); ?>
                                            <div class="wp-travel-average-review" title="<?php printf( esc_attr__( 'Rated %s out of 5', 'travel-master-pro' ), $average_rating ); ?>">
                                                <span style="width:<?php echo esc_attr( ( $average_rating / 5 ) * 100 ); ?>%">
                                                    <strong itemprop="ratingValue" class="rating"><?php echo esc_html( $average_rating ); ?></strong> <?php printf( esc_html__( 'out of %1$s5%2$s', 'travel-master-pro' ), '<span itemprop="bestRating">', '</span>' ); ?>
                                                </span>
                                            </div>
                                        <?php endif;

                                        if ( false !== $sale_enabled && '1' === $sale_enabled ) : ?>
                                            <div class="wp-travel-offer">
                                                <span><?php esc_html_e( 'Offer', 'travel-master-pro' ); ?></span>
                                            </div>
                                        <?php endif;
                                    endif; ?>
                                </div><!-- .featured-image -->

                                <div class="entry-container clear">
                                    <header class="entry-header">
                                        <h2 class="entry-title"><a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html( $content['title'] ); ?></a></h2>
                                        <?php if ( ! in_array( $popular_destination_content_type, array( 'category', 'page', 'post' ) ) ) : 
                                            $terms = wp_get_post_terms( $content['id'], 'travel_locations' );
                                            ?>
                                            <span>
                                                <?php foreach ( $terms as $term ) : ?>
                                                    <a href="<?php echo esc_url( get_term_link( $term->term_id, 'travel_locations' ) ); ?>"><?php echo esc_html( $term->name ); ?></a>
                                                <?php endforeach; ?>
                                            </span>
                                        <?php endif; ?>
                                    </header>   

                                    <div class="price-wrapper">
                                        <?php if ( ! in_array( $popular_destination_content_type, array( 'category', 'page', 'post' ) ) ) : ?>
                                            <span class="trip-price">                       
                                                <?php echo wp_travel_get_formated_price_currency( $trip_price ); ?>
                                            </span><!-- .trip-price -->
                                        <?php endif;
                                        
                                        if ( ! empty( $options['popular_destination_read_more'] ) ) : ?>
                                            <a href="<?php echo esc_url( $content['url'] ); ?>" class="more-link"><?php echo esc_html( $options['popular_destination_read_more'] ); ?></a>
                                        <?php endif; ?>
                                    </div><!-- .price-wrapper -->
                                </div><!-- .entry-container -->
                            </div><!-- .destination-item-wrapper -->
                        </article>
                    <?php endforeach; ?>
                    
                </div><!-- .section-content -->

                <?php if ( ! empty( $options['popular_destination_btn_title'] ) && ! empty( $options['popular_destination_btn_url'] ) ) : ?>
                    <div class="read-more">
                        <a href="<?php echo esc_url( $options['popular_destination_btn_url'] ); ?>" class="more-link">
                            <?php 
                                echo esc_html( $options['popular_destination_btn_title'] );
                                echo travel_master_pro_get_svg( array( 'icon' => 'right' ) ); 
                            ?>
                        </a>
                    </div>
                <?php endif; ?>
            </div><!-- .wrapper -->
        </div><!-- #top-destinations -->
        
    <?php }
endif;